# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.map_layer import MapLayer
from ...types.weather_layer import WeatherLayer

ListLayersApiV1DashboardLayersGetResponseItem = typing.Union[WeatherLayer, MapLayer]
