# This file was auto-generated by Fern from our API Definition.

import typing

UpdateLayerApiV1DashboardLayersLayerIdPutRequestMapLayerType = typing.Union[
    typing.Literal["ScatterPlotLayer", "GeoJsonLayer"], typing.Any
]
